//
//  XYViewController.m
//  MemoryDemo
//
//  Created by Tim Nugent on 7/02/2014.
//  Copyright (c) 2014 Tim Nugent. All rights reserved.
//

#import "XYViewController.h"

@interface XYViewController ()
@property (weak, nonatomic) IBOutlet UIScrollView *imagesContainer;

@end

@implementation XYViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
	
	NSInteger imageCount = 1000;
	
	for (int i = 1; i < imageCount; i++)
	{
		[self loadPageWithNumber:i];
	}
	
	CGSize contentSize;
	contentSize.height = self.imagesContainer.bounds.size.height;
	contentSize.width = self.imagesContainer.bounds.size.width * imageCount;
	
	[self.imagesContainer setContentSize:contentSize];
}

// this method creates an image that we will be inserting into the scrollview
- (UIImage *)imageWithNumber:(NSInteger)number
{
	CGRect imageRect = self.imagesContainer.frame;
	
	UIGraphicsBeginImageContext(imageRect.size);
	
	// inset in by 30 pixels so we can see the rounded corner
	imageRect = CGRectInset(imageRect, 30, 30);
	
	// draw a rounded rectangle with black borders and a purple fill
	UIBezierPath *path = [UIBezierPath bezierPathWithRoundedRect:imageRect cornerRadius:30];
	[path setLineWidth:20];
	[[UIColor blackColor] setStroke];
	[[UIColor purpleColor] setFill];
	
	[path fill];
	[path stroke];
	
	// draw the number inside the image
	NSString *label = [NSString stringWithFormat:@"Number %ld",(long)number];
	UIFont *font = [UIFont systemFontOfSize:50];
	CGPoint labelPoint = CGPointMake(50, 50);
	[[UIColor whiteColor] setFill];
	[label drawAtPoint:labelPoint withAttributes:@{@"font": font}];
	
	// get the finished image and return it
	UIImage *returnedImage = UIGraphicsGetImageFromCurrentImageContext();
	UIGraphicsEndImageContext();
	
	return returnedImage;
}

// this method loads an image for the number, and then adds it to the scrollview
- (void)loadPageWithNumber:(NSInteger)number
{
	// if an image already exists for this number, do nothing
	if ([self.imagesContainer viewWithTag:number])
		return;
	
	// get the image for this page
	UIImage *image = [self imageWithNumber:number];
	
	// create and prepare an imageview for this image
	UIImageView *imageView = [[UIImageView alloc] initWithImage:image];
	
	CGRect imageViewFrame = self.imagesContainer.bounds;
	imageViewFrame.origin.x = imageViewFrame.size.width * (number - 1);
	imageView.frame = imageViewFrame;
	
	// add it to the scroll view
	[self.imagesContainer addSubview:imageView];
	imageView.tag = number;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
